# arth_temperature

## A package to convert temperature from one scale to another

---

# Use the package in your project

### Install the package

```
pip install arth-temperature
```

### Using the package

```
import arth_temperature.temperature as temperature

temperature.celsius_to_fahrenheit(100)
```

---

Arth Jaiswal © 2023

> **Note**
> This is for a university project. Might not be maintained in future.
